@@ -1,15 +1,15 @@
 from typing import Optional
 
 from MSApi.Assortment import Assortment
-from MSApi.ObjectMS import check_init
-from MSApi.ProductFolder import ProductFolder
 from MSApi.mixin import AttributeMixin, SalePricesMixin, GenerateListMixin, ProductfolderMixin
+from MSApi.mixin.NameMixin import NameMixin
 
 
 class Bundle(Assortment,
              AttributeMixin,
              SalePricesMixin,
              GenerateListMixin,
-             ProductfolderMixin):
+             ProductfolderMixin,
+             NameMixin):
 
     _type_name = 'bundle'
