@@ -6,8 +6,15 @@ from MSApi.documents.DocumentMS import DocumentMS
 from MSApi.MSLowApi import MSLowApi, error_handler, caching
 from MSApi.State import State
 
+from MSApi.mixin.GenListMixin import GenerateListMixin
+from MSApi.mixin.StateMixin import StateMixin
+from MSApi.mixin.CreateNewMixin import CreateNewMixin
 
-class Processing(DocumentMS):
+
+class Processing(DocumentMS,
+                 GenerateListMixin,
+                 StateMixin,
+                 CreateNewMixin):
 
     @classmethod
     @caching
@@ -25,21 +32,7 @@ class Processing(DocumentMS):
         error_handler(response)
         return Processing(response.json())
 
-    @classmethod
-    def gen_states(cls):
-        response = MSLowApi.auch_get(f"entity/processing/metadata")
-        error_handler(response)
-        for states_json in response.json()["states"]:
-            yield State(states_json)
-
-    def __init__(self, json):
-        super().__init__(json)
-
     def create(self, **kwargs):
         response = MSLowApi.auch_post(f'entity/processing', json=self.get_json(), **kwargs)
         error_handler(response)
         self._json = response.json()
-
-    @check_init
-    def get_state(self) -> Optional[State]:
-        return self._get_optional_object('state', State)
