@@ -1,4 +1,7 @@
 
+from json.decoder import JSONDecodeError
+
+
 class MSApiException(Exception):
     pass
 
@@ -7,9 +10,7 @@ class MSApiHttpException(MSApiException):
     def __init__(self, response):
         self.errors = []
         self.status_code = response.status_code
-        if self.status_code in [503]:
-            self.errors.append(str(response.text))
-        else:
+        try:
             json = response.json()
             if json is list:
                 for local in json:
@@ -18,6 +19,8 @@ class MSApiHttpException(MSApiException):
             else:
                 for json_error in json.get('errors'):
                     self.errors.append(json_error.get('error'))
+        except JSONDecodeError as e:
+            self.errors.append(str(response.text))
 
     def __str__(self):
-        return '{}'.format("\n".join(self.errors))
+        return '[{}] {}'.format(self.status_code, "\n".join(self.errors))
